@@ -501,10 +501,8 @@ int general_send_command(const char* buf, MDI_Comm comm) {
   for ( ichar=0; ichar < MDI_COMMAND_LENGTH; ichar++) {
     command[ichar] = '\0';
   }
-  if ( this_code->intra_rank == 0 ) {
-    for ( ichar=0; ichar < strlen(buf) && ichar < MDI_COMMAND_LENGTH; ichar++ ) {
-      command[ichar] = buf[ichar];
-    }
+  for ( ichar=0; ichar < strlen(buf) && ichar < MDI_COMMAND_LENGTH; ichar++ ) {
+    command[ichar] = buf[ichar];
   }
 
   ret = selected_method->on_send_command(command, comm, &skip_flag);
@@ -1297,11 +1295,20 @@ vector* get_node_vector(MDI_Comm comm) {
   }
   else {
     communicator* this = get_communicator(current_code, comm);
-    if ( this->nodes->size == 0 ) {
-      // acquire node information for this communicator
-      get_node_info(comm);
+    if ( this->method == MDI_LINK ) {
+      // get the engine code to which this communicator connects
+      library_data* libd = (library_data*) this->method_data;
+      int iengine = libd->connected_code;
+      code* engine_code = get_code(iengine);
+      node_vec = engine_code->nodes;
+    }
+    else {
+      if ( this->nodes->size == 0 ) {
+        // acquire node information for this communicator
+        get_node_info(comm);
+      }
+      node_vec = this->nodes;
     }
-    node_vec = this->nodes;
   }
   return node_vec;
 }
