@@ -61,40 +61,37 @@ int mpi_on_selection() {
 
   // ensure MPI has been initialized
   int mpi_init_flag = 0;
-  if ( this_code->language != MDI_LANGUAGE_PYTHON ) {
 
+  ret = MPI_Initialized(&mpi_init_flag);
+  if ( ret != 0 ) {
+    mdi_error("Error in MDI_Init: MPI_Initialized failed");
+    return ret;
+  }
+
+  if ( mpi_init_flag == 0 ) {
+
+    // initialize MPI
+    int mpi_argc = 0;
+    char** mpi_argv;
+    ret = MPI_Init( &mpi_argc, &mpi_argv );
+    if ( ret != 0 ) {
+      mdi_error("Error in MDI_Init: MPI_Init failed");
+      return ret;
+    }
+
+    // confirm that MPI is now initialized
+    // if it isn't, that indicates that the MPI stubs are being used
     ret = MPI_Initialized(&mpi_init_flag);
     if ( ret != 0 ) {
       mdi_error("Error in MDI_Init: MPI_Initialized failed");
       return ret;
     }
-
     if ( mpi_init_flag == 0 ) {
-
-      // initialize MPI
-      int mpi_argc = 0;
-      char** mpi_argv;
-      ret = MPI_Init( &mpi_argc, &mpi_argv );
-      if ( ret != 0 ) {
-	mdi_error("Error in MDI_Init: MPI_Init failed");
-	return ret;
-      }
-
-      // confirm that MPI is now initialized
-      // if it isn't, that indicates that the MPI stubs are being used
-      ret = MPI_Initialized(&mpi_init_flag);
-      if ( ret != 0 ) {
-	mdi_error("Error in MDI_Init: MPI_Initialized failed");
-	return ret;
-      }
-      if ( mpi_init_flag == 0 ) {
-	mdi_error("Error in MDI_Init: Failed to initialize MPI. Check that the MDI Library is linked to an MPI library.");
-	return 1;
-      }
-
-      initialized_mpi = 1;
+      mdi_error("Error in MDI_Init: Failed to initialize MPI. Check that the MDI Library is linked to an MPI library.");
+      return 1;
     }
 
+    initialized_mpi = 1;
   }
 
   // get the appropriate MPI communicator to use
@@ -108,7 +105,7 @@ int mpi_on_selection() {
     mpi_communicator = 0;
   }
   else {
-    if ( this_code->language == MDI_LANGUAGE_PYTHON ) {
+    if ( this_code->language == MDI_LANGUAGE_PYTHON && ( ! initialized_mpi ) ) {
       mpi_communicator = 0;
     }
     else {
@@ -121,7 +118,7 @@ int mpi_on_selection() {
 
   // determine whether the intra-code MPI communicator should be split
   int use_mpi4py = 0;
-  if ( this_code->language == MDI_LANGUAGE_PYTHON ) {
+  if ( this_code->language == MDI_LANGUAGE_PYTHON && ( ! initialized_mpi ) ) {
     use_mpi4py = 1;
   }
 
